@@ -269,6 +269,17 @@ plot(st_sfc(st_linestring(cbind(c(0,1,0,1,0),c(0,1,1,0,0)))), type = 'b', axes=F
 title(st_as_text(x3))
 par(opar)
 
+## ------------------------------------------------------------------------
+a <- st_area(nc[1,])
+attributes(a)
+
+## ------------------------------------------------------------------------
+units::set_units(a, km^2) # result in square kilometers
+units::set_units(a, ha) # result in hectares
+
+## ------------------------------------------------------------------------
+as.numeric(a)
+
 ## ------------------------------------------------------------------------
 nc <- st_read(system.file("shape/nc.shp", package="sf"),
     agr = c(AREA = "aggregate", PERIMETER = "aggregate", CNTY_ = "identity",
