@@ -100,6 +100,7 @@ ls - 2
 str(x)
 nc = st_read(system.file("shape/nc.shp", package="sf"), quiet = TRUE)
 str(nc)
+st_as_sfc(st_bbox(nc))
 
 st_agr("constant")
 st_agr()
@@ -170,3 +171,6 @@ st_sample(nc[1:2,], size = c(10,20))
 class(dplyr::bind_cols(nc, as.data.frame(nc)[1:3]))
 class(rbind(nc, nc))
 class(cbind(nc, nc))
+
+x = st_sfc(st_point(0:1), st_point(2:3))
+x[c(NA,1,NA,2,NA)]
